/*
 * low-speed-spidev board file, modified for Seco Board
 * Copyright (c) 2014, Intel Corporation.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU General Public License,
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * Author: California Sullivan <california.l.sullivan@intel.com>
 */

#define pr_fmt(fmt) "seco-spi: " fmt

#include <linux/platform_device.h>
#include <linux/module.h>
#include <linux/spi/spi.h>

#if (!defined(CONFIG_SPI_SPIDEV_MODULE) && !defined(CONFIG_SPI_SPIDEV))
        #error SPI_SPIDEV is required.
#endif

/* Change these values to what your board uses. */
#define SPIDEV_SPI_BUS_0 0
#define SPIDEV_SPI_BUS_1 1
#define SPIDEV_SPI_CS_0 0
#define SPIDEV_SPI_CS_1 1
#define SPIDEV_MAX_CLK_HZ 1000000

static struct spi_board_info spi_board_info[] __initdata = {
{
	.modalias	= "spidev",
	.bus_num	= SPIDEV_SPI_BUS_0,
	.chip_select	= SPIDEV_SPI_CS_0,
	.max_speed_hz   = SPIDEV_MAX_CLK_HZ,
},
{
	.modalias	= "spidev",
	.bus_num	= SPIDEV_SPI_BUS_0,
	.chip_select	= SPIDEV_SPI_CS_1,
	.max_speed_hz   = SPIDEV_MAX_CLK_HZ,
},
{
	.modalias	= "spidev",
	.bus_num	= SPIDEV_SPI_BUS_1,
	.chip_select	= SPIDEV_SPI_CS_0,
	.max_speed_hz   = SPIDEV_MAX_CLK_HZ,
},
{
	.modalias	= "spidev",
	.bus_num	= SPIDEV_SPI_BUS_1,
	.chip_select	= SPIDEV_SPI_CS_1,
	.max_speed_hz   = SPIDEV_MAX_CLK_HZ,
}
};

static struct spi_device *dev;

static int __init spidev_module_init(void)
{
	struct spi_master *master;
	int err, a;

	err = 0;
	
	for(a = 0; a < ARRAY_SIZE(spi_board_info); a++)
	{
		pr_info("module init\n");		

		master = spi_busnum_to_master(spi_board_info[a].bus_num);
		pr_info("master=%p\n", master);
		if (!master)
			pr_err("Failed to register SPI device\n");
		else
		{
			dev = spi_new_device(master, &spi_board_info[a]);
			pr_info("dev=%p\n", dev);
			if (!dev)
				pr_err("Failed to register SPI device\n");
			else
			{
				pr_info("spidev registered\n");
				err = -ENODEV;
			}
		}
	}

	return err;
}

static void __exit spidev_module_exit(void)
{
	pr_info("module exit");
	if (dev)
		spi_unregister_device(dev);
}

module_init(spidev_module_init);
module_exit(spidev_module_exit);

MODULE_LICENSE("GPL");
